MethodChannelFlutterSerialCommunication class

An implementation of FlutterSerialCommunicationPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(DeviceInfo deviceInfo, int baudRate) → Future<bool>
Connect to device using DeviceInfo
override
disconnect() → Future<void>
Disconnects from connected device
override
getAvailableDevices() → Future<List<DeviceInfo>>
Get list of available DeviceInfo
override
getDeviceConnectionListener() → EventChannel
Listen to device connection status
override
getSerialMessageListener() → EventChannel
Listen to message received from serial port
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeHwBuffers(bool purgeWriteBuffers, bool purgeReadBuffers) → Future<bool>
override
setDTR(bool set) → Future<bool>
Set usb DTR
override
setParameters(int baudRate, int dataBits, int stopBits, int parity) → Future<bool>
Set connection parameters
override
setRTS(bool set) → Future<bool>
Set usb RTS
override
toString() → String
A string representation of this object.
inherited
write(Uint8List data) → Future<bool>
Send data to serial port using Uint8List
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited