FlutterSerialCommunicationPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterSerialCommunicationPlatform
Implementers

Constructors

FlutterSerialCommunicationPlatform()
Constructs a FlutterSerialCommunicationPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(DeviceInfo deviceInfo, int baudRate) → Future<bool>
disconnect() → Future<void>
getAvailableDevices() → Future<List<DeviceInfo>>
getDeviceConnectionListener() → EventChannel
getSerialMessageListener() → EventChannel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeHwBuffers(bool purgeWriteBuffers, bool purgeReadBuffers) → Future<void>
setDTR(bool set) → Future<void>
setParameters(int baudRate, int dataBits, int stopBits, int parity) → Future<void>
setRTS(bool set) → Future<void>
toString() → String
A string representation of this object.
inherited
write(Uint8List data) → Future<bool>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterSerialCommunicationPlatform
The default instance of FlutterSerialCommunicationPlatform to use.
getter/setter pair