DeviceInfo class

Constructors

DeviceInfo({int? deviceId = 0, String version = '', String deviceName = '', String manufacturerName = '', String productName = '', int? productId = 0, int? vendorId = 0, String serialNumber = ''})
DeviceInfo.fromJson(String source)
factory
DeviceInfo.fromMap(Map<String, dynamic> map)
factory

Properties

deviceId → int?
final
deviceName → String
final
hashCode → int
The hash code for this object.
no setterinherited
manufacturerName → String
final
productId → int?
final
productName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String
final
vendorId → int?
final
version → String
final

Methods

copyWith({int? deviceId, String? version, String? deviceName, String? manufacturerName, String? productName, int? productId, int? vendorId, String? serialNumber}) → DeviceInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited